/**
* This file is a part of the Cairo-Dock project
*
* Copyright : (C) see the 'copyright' file.
* E-mail    : see the 'copyright' file.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 3
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef __APPLET_NOTIFICATIONS__
#define  __APPLET_NOTIFICATIONS__


#include <cairo-dock.h>

gboolean _check_size_is_constant (CairoDockModuleInstance *myApplet, const gchar *cFilePath);
gboolean _new_xml_to_conf (CairoDockModuleInstance *myApplet, gchar *cReceivedData);

//~ CD_APPLET_ON_CLICK_H
//~ CD_APPLET_ON_DOUBLE_CLICK_H

CD_APPLET_ON_BUILD_MENU_H

//~ CD_APPLET_ON_SCROLL_H
CD_APPLET_ON_DROP_DATA_H

CD_APPLET_ON_MIDDLE_CLICK_H


#endif
